Supports the ability to evaluation code. The name of the middleware is slightly misleading, as interrupt is currently supported at a session level but the name is retained for backwards compatibility.
Supports the ability to evaluation code. The name of the middleware is slightly misleading, as interrupt is currently supported at a session level but the name is retained for backwards compatibility.
The message currently being evaluated.
The message currently being evaluated.
(evaluator msg)Return a closure that evaluates msg's :code (either a string or a seq of
forms to be evaluated) within the dynamic context of its session. :ns can be
optionally specified (resolved via find-ns). The message MUST contain a
Transport implementation in :transport; expression results and errors will be
sent via that Transport.
Return a closure that evaluates msg's `:code` (either a string or a seq of forms to be evaluated) within the dynamic context of its session. `:ns` can be optionally specified (resolved via `find-ns`). The message MUST contain a Transport implementation in :transport; expression results and errors will be sent via that Transport.
(interruptible-eval h & _configuration)Evaluation middleware that supports interrupts. Returns a handler that supports "eval" and "interrupt" :op-erations that delegates to the given handler otherwise.
Evaluation middleware that supports interrupts. Returns a handler that supports "eval" and "interrupt" :op-erations that delegates to the given handler otherwise.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |