nrepl.middleware.io

Forward output from System/out, System/err, and root *out* and *err* to clients that requested such forwarding.

Forward output from `System/out`, `System/err`, and root `*out*` and `*err*`
to clients that requested such forwarding.
raw docstring

forward-system-output-replyclj

(forward-system-output-reply {:keys [session] :as msg})

Add msg to tracked-sessions-map.

Add msg to `tracked-sessions-map`.
sourceraw docstring

wrap-outclj

(wrap-out handler)

Enable forwarding of System/out and System/err output to client. To cancel forwarding, discard the current session and create a new one.

NB: do not enable stdout forwarding if the client runs inside the same process as the server. This will lead to an infinite loop.

Enable forwarding of System/out and System/err output to client. To cancel
forwarding, discard the current session and create a new one.

NB: do not enable stdout forwarding if the client runs inside the same process
as the server. This will lead to an infinite loop.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries