Clojure only.

nrepl.middleware.load-file

Middleware for loading entire files.

Delegates to interruptible-eval for reading and evaluation while ensuring proper source file metadata (path, name, line numbers) is set for the compiler.

Middleware for loading entire files.

Delegates to `interruptible-eval` for reading and evaluation while
ensuring proper source file metadata (path, name, line numbers) is
set for the compiler.
raw docstring

wrap-load-fileclj

(wrap-load-file h)

Middleware that evaluates a file's contents, as per load-file, but with all data supplied in the sent message (i.e. safe for use with remote REPL environments).

This middleware depends on the availability of an :op "eval" middleware below it (such as interruptible-eval).

Middleware that evaluates a file's contents, as per load-file,
but with all data supplied in the sent message (i.e. safe for use
with remote REPL environments).

This middleware depends on the availability of an :op "eval"
middleware below it (such as interruptible-eval).
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries