nrepl.util.classloader

Creating and managing classloaders supplied to evaluated code.

Creating and managing classloaders supplied to evaluated code.
raw docstring

nrepl.util.jvmti

This namespace contains code exclusive to JDK9+ and should not be attempted to load with earlier JDKs.

This namespace contains code exclusive to JDK9+ and should not be attempted to
load with earlier JDKs.
raw docstring

nrepl.util.lookup

Symbol info lookup.

It's meant to provide you with useful data like definition location, parameter lists, etc.

NOTE: The functionality here is experimental and the API is subject to changes.

Symbol info lookup.

It's meant to provide you with useful data like definition location,
parameter lists, etc.

NOTE: The functionality here is experimental and
the API is subject to changes.
raw docstring

nrepl.util.out

Utilities for injecting output-intercepting writers for System.out and err.

Utilities for injecting output-intercepting writers for System.out and err.
raw docstring

nrepl.util.print

Pretty-print related utilities. All functions here are simple wrappers compatible with the expectations of nrepl.middleware.print/wrap-print.

Pretty-print related utilities.
All functions here are simple wrappers compatible with the expectations of
nrepl.middleware.print/wrap-print.
raw docstring

nrepl.util.threading

Functions and tools for dealing with all threads and threadpools necessary for nREPL operation.

Functions and tools for dealing with all threads and threadpools necessary for
nREPL operation.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries