Creating and managing classloaders supplied to evaluated code.
Creating and managing classloaders supplied to evaluated code.
(dynamic-classloader)(dynamic-classloader classloader)Return the topmost DynamicClassLoader if it is present among the parents of the
given classloader, otherwise create a new DynamicClassLoader. classloader
defaults to thread's context classloader if not provided.
Return the topmost DynamicClassLoader if it is present among the parents of the given classloader, otherwise create a new DynamicClassLoader. `classloader` defaults to thread's context classloader if not provided.
(find-topmost-dcl cl)Try to find and return the highest level DynamicClassLoader instance in the given classloader chain. If not a single DCL is found, return nil.
Try to find and return the highest level DynamicClassLoader instance in the given classloader chain. If not a single DCL is found, return nil.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |