This namespace contains code exclusive to JDK9+ and should not be attempted to load with earlier JDKs.
This namespace contains code exclusive to JDK9+ and should not be attempted to load with earlier JDKs.
(stop-thread thread)Stop the given thread using JVMTI StopThread function. Risks state
corruption. Should not be used prior to JDK20.
Stop the given `thread` using JVMTI StopThread function. Risks state corruption. Should not be used prior to JDK20.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |