Symbol info lookup.
It's meant to provide you with useful data like definition location, parameter lists, etc.
NOTE: The functionality here is experimental and the API is subject to changes.
Symbol info lookup. It's meant to provide you with useful data like definition location, parameter lists, etc. NOTE: The functionality here is experimental and the API is subject to changes.
(lookup ns sym)Lookup the metadata for sym.
If the sym is not qualified than it will be resolved in the context
of ns.
Lookup the metadata for `sym`. If the `sym` is not qualified than it will be resolved in the context of `ns`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |