Pretty-print related utilities. All functions here are simple wrappers compatible with the expectations of nrepl.middleware.print/wrap-print.
Pretty-print related utilities. All functions here are simple wrappers compatible with the expectations of nrepl.middleware.print/wrap-print.
(pprint value writer)(pprint value writer options)A simple wrapper around clojure.pprint/write.
A simple wrapper around `clojure.pprint/write`.
(pr value writer)(pr value writer options)Equivalent to clojure.core/pr. Any options corresponding to dynamic
printing configuration vars in clojure.core will, if provided, be bound
accordingly (e.g. clojure.core/*print-length* will be used if
:print-length is provided).
Equivalent to `clojure.core/pr`. Any options corresponding to dynamic printing configuration vars in `clojure.core` will, if provided, be bound accordingly (e.g. `clojure.core/*print-length*` will be used if `:print-length` is provided).
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |