Forward output from System/out, System/err, and root *out* and *err*
to clients that requested such forwarding.
Forward output from `System/out`, `System/err`, and root `*out*` and `*err*` to clients that requested such forwarding.
(forward-system-output-reply {:keys [session] :as msg})Add msg to tracked-sessions-map.
Add msg to `tracked-sessions-map`.
(wrap-out handler)Enable forwarding of System/out and System/err output to client. To cancel forwarding, discard the current session and create a new one.
NB: do not enable stdout forwarding if the client runs inside the same process as the server. This will lead to an infinite loop.
Enable forwarding of System/out and System/err output to client. To cancel forwarding, discard the current session and create a new one. NB: do not enable stdout forwarding if the client runs inside the same process as the server. This will lead to an infinite loop.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |